# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`afs`](#afs): Install and configure AFS

#### Private Classes

* `afs::config`: configures afs packages
* `afs::firewall`: Maintain firewall entries
* `afs::install`: Installs afs packages
* `afs::kojitag`: Configure afs koji repositories
* `afs::params`: Defaults for afs module
* `afs::service`: Control afs sserice

## Classes

### <a name="afs"></a>`afs`

Install and configure AFS

#### Examples

##### Simple Example

```puppet
include afs
```

##### Use AFS Cache in Memory

```puppet
class{'afs':
  memcachesize => 524288,
  options      => {
    memcache => true,
  },
}
```

##### Enable aklog's -d debug option

```puppet
class{'afs':
  pam_afs_session_debug = true,
 }
```

#### Parameters

The following parameters are available in the `afs` class:

* [`thiscell`](#thiscell)
* [`cachesize`](#cachesize)
* [`memcachesize`](#memcachesize)
* [`options`](#options)
* [`enable_firewall`](#enable_firewall)
* [`runserver`](#runserver)
* [`prefer_upstream_dkms`](#prefer_upstream_dkms)
* [`aklog_unit`](#aklog_unit)
* [`pam_afs_session`](#pam_afs_session)
* [`pam_afs_session_debug`](#pam_afs_session_debug)
* [`handle_cellservdb`](#handle_cellservdb)
* [`use_osrepos`](#use_osrepos)
* [`tools`](#tools)

##### <a name="thiscell"></a>`thiscell`

Data type: `String`

name of the AFS cell this client belongs to

Default value: `$afs::params::thiscell`

##### <a name="cachesize"></a>`cachesize`

Data type: `Variant[Enum['AUTOMATIC'], Pattern[/\A\d+\z/], Integer[0]]`

disk cache size

Default value: `$afs::params::cachesize`

##### <a name="memcachesize"></a>`memcachesize`

Data type: `Variant[Pattern[/\A\d+\z/], Integer[0]]`

memorycachesize

Default value: `$afs::params::memcachesize`

##### <a name="options"></a>`options`

Data type: `Hash`

Hash of permissable TDB

Default value: `$afs::params::options`

##### <a name="enable_firewall"></a>`enable_firewall`

Data type: `Boolean`

open AFS client callback port (UDP/7001) in the firewall

Default value: `$afs::params::enable_firewall`

##### <a name="runserver"></a>`runserver`

Data type: `Enum['on','off']`

run an afs server or not

Default value: `$afs::params::runserver`

##### <a name="prefer_upstream_dkms"></a>`prefer_upstream_dkms`

Data type: `Boolean`

use dkms module

Default value: `$afs::params::prefer_upstream_dkms`

##### <a name="aklog_unit"></a>`aklog_unit`

Data type: `Boolean`

install and enable systemd user service aklog.service C8 and newer only.

Default value: `$afs::params::aklog_unit`

##### <a name="pam_afs_session"></a>`pam_afs_session`

Data type: `Boolean`

install and configure pam_afs_session in sshd pamstack. C8 and newer only.

Default value: `$afs::params::pam_afs_session`

##### <a name="pam_afs_session_debug"></a>`pam_afs_session_debug`

Data type: `Boolean`

If true aklog will be called  with the -d option

Default value: ``false``

##### <a name="handle_cellservdb"></a>`handle_cellservdb`

Data type: `Boolean`

let the module handle the client CellServDB files. On by default.

Default value: `$afs::params::handle_cellservdb`

##### <a name="use_osrepos"></a>`use_osrepos`

Data type: `Boolean`

allows to _not_ rely on the 'openafs' KOJI repository

Default value: `$afs::params::use_osrepos`

##### <a name="tools"></a>`tools`

Data type: `Boolean`

Install afs_tools/afs_tools_standalone package, EL7 and 8 only.

Default value: ``false``

